pub struct ExtractOperation<'c> { /* private fields */ }Expand description
An extract operation. Extract the item at the specified index in a range.
pdl_interp.extract operations are used to extract an item from a range
at the specified index. If the index is out of range, returns null.
Example:
// Extract the value at index 1 from a range of values.
%ops = pdl_interp.extract 1 of %values : !pdl.valueImplementations
Sourceimpl<'c> ExtractOperation<'c>
impl<'c> ExtractOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> ExtractOperationBuilder<'c, Unset, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> ExtractOperationBuilder<'c, Unset, Unset, Unset>
Creates a builder.
pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn range(&self) -> Result<Value<'c, '_>, Error>
pub fn index(&self) -> Result<IntegerAttribute<'c>, Error>
pub fn set_index(&mut self, value: IntegerAttribute<'c>)